@@ -151,21 +151,30 @@ public class Fingerprint extends TreeMap<HaplotypeBlock, HaplotypeProbabilities>
                 .collect(Collectors.toMap(
                         entry -> {
                             // merge the keys (unequal values are eliminated by merge).
-
-                            final FingerprintIdDetails finalId = new FingerprintIdDetails();
-                            entry.getValue().forEach(id -> finalId.merge(id.getKey()));
+                            final List<Map.Entry<FingerprintIdDetails, Fingerprint>> entryList = entry.getValue();
+                            final FingerprintIdDetails finalId;
+                            if (entryList.size() == 1) {
+                                finalId = entryList.get(0).getKey();
+                            } else {
+                                finalId = new FingerprintIdDetails();
+                                entryList.forEach(id -> finalId.merge(id.getKey()));
+                            }
                             finalId.group = entry.getKey();
                             return finalId;
 
                         }, entry -> {
                             // merge the values by merging the fingerprints.
 
-                            final FingerprintIdDetails firstDetail = entry.getValue().get(0).getKey();
                             //use the "by" function to determine the "info" part of the fingerprint
-                            final Fingerprint sampleFp = new Fingerprint(firstDetail.sample, null, by.apply(firstDetail));
-                            entry.getValue().stream().map(Map.Entry::getValue).collect(Collectors.toSet()).forEach(sampleFp::merge);
-                            return sampleFp;
+                            final Set<Fingerprint> fingerprintsSet = entry.getValue().stream().map(Map.Entry::getValue).collect(Collectors.toSet());
+                            if (fingerprintsSet.size() == 1) {
+                                return fingerprintsSet.iterator().next();
+                            }
+                            final FingerprintIdDetails firstDetail = entry.getValue().get(0).getKey();
+                            final Fingerprint mergedFp = new Fingerprint(firstDetail.sample, null, by.apply(firstDetail));
 
+                            fingerprintsSet.forEach(mergedFp::merge);
+                            return mergedFp;
                         }));
     }
 
